@@ -1,11 +1,7 @@
 # -*- coding: UTF-8 -*-
 import os
-import sys
-import argparse 
-import psutil
-from jproperties import Properties
 
-# from kupy.logger import logger
+from jproperties import Properties
 
 configs = Properties()
 default_setting = {
@@ -16,7 +12,7 @@ default_setting = {
     "postgres_database": "",
     "log_level": "INFO",
     "log_output_path": "",
-    "cache_folder": "/tmp/"
+    "data_folder": "/tmp/",
 }
 # 设置默认值
 for (key, value) in default_setting.items():
@@ -28,14 +24,14 @@ for (key, value) in default_setting.items():
 # print(psutil.Process(pid).)
 
 
-config_path="resources/app-config.properties"
+config_path = "resources/app-config.properties"
 if os.path.exists(config_path):
     with open(config_path, "rb") as config_file:
         configs.load(config_file)
-        if configs.get("cache_folder") is not None:
-            cache_folder = configs["cache_folder"].data
-            if not os.path.exists(cache_folder):
-                os.makedirs(cache_folder, 755)
+        if configs.get("data_folder") is not None:
+            data_folder = configs["data_folder"].data
+            if not os.path.exists(data_folder + "cache/"):
+                os.makedirs(data_folder, 755)
 
 if not configs["log_output_path"]:
     log_file_path = configs["log_output_path"].data
